#[non_exhaustive]pub struct AsyncInstrumentBuilder<'a, I, M> {
pub instrument_provider: &'a dyn InstrumentProvider,
pub name: Cow<'static, str>,
pub description: Option<Cow<'static, str>>,
pub unit: Option<Cow<'static, str>>,
pub callbacks: Vec<Callback<M>>,
/* private fields */
}metrics only.Expand description
Configuration for building an async instrument.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.instrument_provider: &'a dyn InstrumentProviderInstrument provider is used to create the instrument.
name: Cow<'static, str>Name of the instrument.
description: Option<Cow<'static, str>>Description of the instrument.
unit: Option<Cow<'static, str>>Unit of the instrument.
callbacks: Vec<Callback<M>>Callbacks to be called for this instrument.
Implementations
Sourceimpl<'a, I, M> AsyncInstrumentBuilder<'a, I, M>
impl<'a, I, M> AsyncInstrumentBuilder<'a, I, M>
Sourcepub fn with_description<S: Into<Cow<'static, str>>>(
self,
description: S,
) -> Self
pub fn with_description<S: Into<Cow<'static, str>>>( self, description: S, ) -> Self
Set the description for this instrument
Sourcepub fn with_unit<S: Into<Cow<'static, str>>>(self, unit: S) -> Self
pub fn with_unit<S: Into<Cow<'static, str>>>(self, unit: S) -> Self
Set the unit for this instrument.
Unit is case sensitive(kb is not the same as kB).
Unit must be:
- ASCII string
- No longer than 63 characters
Sourcepub fn with_callback<F>(self, callback: F) -> Self
pub fn with_callback<F>(self, callback: F) -> Self
Set the callback to be called for this instrument.
Sourceimpl<'a> AsyncInstrumentBuilder<'a, ObservableCounter<u64>, u64>
impl<'a> AsyncInstrumentBuilder<'a, ObservableCounter<u64>, u64>
Sourcepub fn build(self) -> ObservableCounter<u64>
pub fn build(self) -> ObservableCounter<u64>
Validates the instrument configuration and creates a new ObservableCounter<u64>.
In case of invalid configuration, a no-op instrument is returned
and an error is logged using internal logging.
Sourceimpl<'a> AsyncInstrumentBuilder<'a, ObservableCounter<f64>, f64>
impl<'a> AsyncInstrumentBuilder<'a, ObservableCounter<f64>, f64>
Sourcepub fn build(self) -> ObservableCounter<f64>
pub fn build(self) -> ObservableCounter<f64>
Validates the instrument configuration and creates a new ObservableCounter<f64>.
In case of invalid configuration, a no-op instrument is returned
and an error is logged using internal logging.
Sourceimpl<'a> AsyncInstrumentBuilder<'a, ObservableGauge<u64>, u64>
impl<'a> AsyncInstrumentBuilder<'a, ObservableGauge<u64>, u64>
Sourcepub fn build(self) -> ObservableGauge<u64>
pub fn build(self) -> ObservableGauge<u64>
Validates the instrument configuration and creates a new ObservableGauge<u64>.
In case of invalid configuration, a no-op instrument is returned
and an error is logged using internal logging.
Sourceimpl<'a> AsyncInstrumentBuilder<'a, ObservableGauge<f64>, f64>
impl<'a> AsyncInstrumentBuilder<'a, ObservableGauge<f64>, f64>
Sourcepub fn build(self) -> ObservableGauge<f64>
pub fn build(self) -> ObservableGauge<f64>
Validates the instrument configuration and creates a new ObservableGauge<f64>.
In case of invalid configuration, a no-op instrument is returned
and an error is logged using internal logging.
Sourceimpl<'a> AsyncInstrumentBuilder<'a, ObservableGauge<i64>, i64>
impl<'a> AsyncInstrumentBuilder<'a, ObservableGauge<i64>, i64>
Sourcepub fn build(self) -> ObservableGauge<i64>
pub fn build(self) -> ObservableGauge<i64>
Validates the instrument configuration and creates a new ObservableGauge<i64>.
In case of invalid configuration, a no-op instrument is returned
and an error is logged using internal logging.
Sourceimpl<'a> AsyncInstrumentBuilder<'a, ObservableUpDownCounter<i64>, i64>
impl<'a> AsyncInstrumentBuilder<'a, ObservableUpDownCounter<i64>, i64>
Sourcepub fn build(self) -> ObservableUpDownCounter<i64>
pub fn build(self) -> ObservableUpDownCounter<i64>
Validates the instrument configuration and creates a new ObservableUpDownCounter<i64>.
In case of invalid configuration, a no-op instrument is returned
and an error is logged using internal logging.
Sourceimpl<'a> AsyncInstrumentBuilder<'a, ObservableUpDownCounter<f64>, f64>
impl<'a> AsyncInstrumentBuilder<'a, ObservableUpDownCounter<f64>, f64>
Sourcepub fn build(self) -> ObservableUpDownCounter<f64>
pub fn build(self) -> ObservableUpDownCounter<f64>
Validates the instrument configuration and creates a new ObservableUpDownCounter<f64>.
In case of invalid configuration, a no-op instrument is returned
and an error is logged using internal logging.