Available on crate feature
metrics only.Expand description
OpenTelemetry Metrics API
Re-exports
pub use noop::NoopMeterProvider;
Modules
- noop
- No-op OpenTelemetry Metrics Implementation
Structs
- Async
Instrument Builder - Configuration for building an async instrument.
- Bound
Counter - A counter bound to a fixed set of attributes.
- Bound
Histogram - A histogram bound to a fixed set of attributes.
- Counter
- An instrument that records increasing values.
- Gauge
- An instrument that records independent values
- Histogram
- An instrument that records a distribution of values.
- Histogram
Builder - Configuration for building a Histogram.
- Instrument
Builder - Configuration for building a sync instrument.
- Meter
- Provides the ability to create instruments for recording measurements or accepting callbacks to report measurements.
- Observable
Counter - An async instrument that records increasing values.
- Observable
Gauge - An async instrument that records independent readings.
- Observable
UpDown Counter - An async instrument that records increasing or decreasing values.
- UpDown
Counter - An instrument that records increasing or decreasing values.
Traits
- Async
Instrument - An SDK implemented instrument that records measurements via callback.
- Bound
Sync Instrument - A pre-bound synchronous instrument that records measurements without attributes.
Created by calling
bind()on aCounterorHistogramwith a fixed attribute set. - Instrument
Provider - SDK implemented trait for creating instruments
- Meter
Provider - Provides access to named Meter instances, for instrumenting an application or crate.
- Sync
Instrument - An SDK implemented instrument that records measurements synchronously.